@@ -722,7 +722,7 @@ void ButtonColors::init(){
 
 extern "C"
 {
-    KDE_EXPORT TQObject* allocate_config(TDEConfig* config, TQWidget* parent) {
+    TDE_EXPORT TQObject* allocate_config(TDEConfig* config, TQWidget* parent) {
         return(new BaghiraConfig(config, parent));
     }
 }
