@@ -132,7 +132,7 @@ void Applet::initPopup()
 void Applet::windowRemoved(WId w_P)
     // another helping slot
     {
-        windowTitleDict.setAutoDelete(TRUE);
+        windowTitleDict.setAutoDelete(true);
         windowTitleDict.remove(w_P);
     }
     
@@ -590,7 +590,7 @@ void MenuEmbed::sendSyntheticConfigureNotifyEvent()
         c.border_width = 0;
         c.above = None;
         c.override_redirect = 0;
-        XSendEvent( tqt_xdisplay(), c.event, TRUE, StructureNotifyMask, (XEvent*)&c );
+        XSendEvent( tqt_xdisplay(), c.event, true, StructureNotifyMask, (XEvent*)&c );
     }
 }
 
