@@ -432,20 +432,20 @@ bool starter::eventFilter( TQObject*, TQEvent *e )
       {
          mainView->setPixmap(hoverPixmap);
          mainView->repaint();
-         return TRUE;
+         return true;
       }
       case TQEvent::Leave:
       {
          mainView->setPixmap(startMenu->isShown() ? downPixmap : pixmap);
          mainView->repaint();
-         return TRUE;
+         return true;
       }
       case TQEvent::MouseButtonPress:
       {
          if (((TQMouseEvent*)e)->button() == TQt::RightButton)
          {
             configPopup->popup(((TQMouseEvent*)e)->globalPos());
-            return TRUE;
+            return true;
          }
          if (((TQMouseEvent*)e)->button() == TQt::LeftButton)
          {
@@ -453,21 +453,21 @@ bool starter::eventFilter( TQObject*, TQEvent *e )
             mainView->repaint();
             popupMenu();
          }
-         return TRUE;
+         return true;
       }
       case TQEvent::MouseButtonRelease:
       {
          if (((TQMouseEvent*)e)->button() != TQt::LeftButton)
-               return FALSE;
+               return false;
          if (mainView->hasMouse())
             mainView->setPixmap(hoverPixmap);
          else
             mainView->setPixmap(startMenu->isShown() ? downPixmap : pixmap);
          mainView->repaint();
-         return TRUE;
+         return true;
       }
       default:
-         return FALSE;
+         return false;
    }
 }
 
